# Copyright 2013, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Josef Skladanka <jskladan@redhat.com>

from flask import url_for
from vault.serializers import BaseSerializer


class Serializer(BaseSerializer):

    def _serialize_Secret(self, o, **kwargs):
        rv = dict(
            id=o.id,
            name=o.name,
            version=o.version,
            active=o.active,
            value=o.value,
        )

        return {key: self.serialize(value) for key, value in rv.items()}

    def _serialize_Bucket(self, o, **kwargs):
        rv = dict(
            uuid=o.uuid,
            name=o.name,
            active=o.active,
            description=o.description,
#            roles=o.roles,
            secrets=dict([(s.name, s.value) for s in o.secrets if s.active]),
        )

        return {key: self.serialize(value) for key, value in rv.items()}


    def _serialize_BucketRoles(self, o, **kwargs):
        rv = dict(
            user={'id': o.user.id, 'username': o.user.username},
            role=o.role,
        )

        return {key: self.serialize(value) for key, value in rv.items()}
